using System.Security.Cryptography;
using System.Web;
using Newtonsoft.Json;

namespace Infrastructure.Tests;

public class GenericTests
{
    [Fact]
    public void ValueConvertTest()
    {
        const string value = "7";
        var convertedValue = Convert<long>(value);
        Assert.Equal(7, convertedValue);
    }

    private static T Convert<T>(string value) where T : IEquatable<T>
    {
        return (T)System.Convert.ChangeType(value, typeof(T));
    }

    [Fact]
    public void DefaultValueTest()
    {
        const long value = 0L;
        long? nullableValue = null;
        Assert.Equal(default, value);
        Assert.Null(nullableValue);
    }

    [Fact]
    public void HashTest()
    {
        var json = JsonConvert.SerializeObject(323234L);
        var hashBytes = MD5.HashData(Encoding.ASCII.GetBytes(json));
        var hashString = BitConverter.ToString(hashBytes).Replace("-", "").ToLowerInvariant();
        Assert.NotEmpty(hashString);
        Assert.NotNull(hashString);
    }

    [Fact]
    public void EncodeTest()
    {
        var raw =
            "XFwxMC4zMC4yLjIwMFxqenl0MDFc57K+6KOFXOaWveW3peWbvuS4gOe7hFzpobnnm67mlofku7Zc5Li05pe25paH5Lu2XOijhemFjeW8j+WwgeijhVwwM1/lt6XkvZznqbrpl7Rc6KOF6YWN5byP5bCB6KOF5p6E5Lu25bqTXOW5s+mdoi5kd2c=";
        var encoded = HttpUtility.UrlEncode(raw);
        var decoded = HttpUtility.UrlDecode(encoded);
        Assert.Equal(raw, decoded);
    }
}